@@ -1,3 +1,13 @@
+###################################################################
+#  Numexpr - Fast numerical array expression evaluator for NumPy.
+#
+#      License: MIT
+#      Author:  See AUTHORS.txt
+#
+#  See LICENSE.txt and LICENSES/*.txt for details about copyright and
+#  rights to use.
+####################################################################
+
 """Very simple test that compares the speed of operating with
 aligned vs unaligned arrays.
 """
@@ -13,7 +23,7 @@ shape = (1000, 10000)   # multidimensional test
 ne.print_versions()
 
 Z_fast = np.zeros(shape, dtype=[('x',np.float64),('y',np.int64)])
-Z_slow = np.zeros(shape, dtype=[('x',np.float64),('y',np.bool)])
+Z_slow = np.zeros(shape, dtype=[('y1',np.int8),('x',np.float64),('y2',np.int8,(7,))])
 
 x_fast = Z_fast['x']
 t = Timer("x_fast * x_fast", "from __main__ import x_fast")
